==> discosnp_2.3.0.orig.tar.gz: DiscoSnp-2.3.0/tools/kissreads2/src/main.cpp <==

/*****************************************************************************
 *   discoSnp++: discovering polymorphism from raw unassembled NGS reads
 *   A tool from the GATB (Genome Assembly Tool Box)
 *   Copyright (C) 2014  INRIA
 *   Authors: P.Peterlongo, E.Drezen
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as
 *  published by the Free Software Foundation, either version 3 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *****************************************************************************/

/********************************************************************************/

#include <Kissreads2.h>



using namespace gatb::core;
using namespace gatb::core::tools;
using namespace gatb::core::bank;
using namespace gatb::core::kmer::impl;

using namespace gatb::core::system;
using namespace gatb::core::system::impl;

/********************************************************************************/




int main (int argc, char* argv[])
{
    u_int64_t a=17;
    u_int64_t b=32;
    u_int64_t nbcreated ;
    

    
    
    
    // We define a try/catch block in case some method fails (bad filename for instance)
    try
    {
        /** We execute the tool. */
        Kissreads2().run (argc, argv);
    }
    
    catch (OptionFailure& e)
    {
        return e.displayErrors (cout);
    }
    
    catch (Exception& e)
    {
        cerr << "EXCEPTION: " << e.getMessage() << endl;
        return EXIT_FAILURE;
    }
    
    return EXIT_SUCCESS;
}

==> discosnp_4.4.4.orig.tar.gz: DiscoSnp-4.4.4/tools/kissreads2/src/main.cpp <==

/*****************************************************************************
 *   discoSnp++: discovering polymorphism from raw unassembled NGS reads
 *   A tool from the GATB (Genome Assembly Tool Box)
 *   Copyright (C) 2014  INRIA
 *   Authors: P.Peterlongo, E.Drezen
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as
 *  published by the Free Software Foundation, either version 3 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *****************************************************************************/

/********************************************************************************/

#include <Kissreads2.h>



using namespace gatb::core;
using namespace gatb::core::tools;
using namespace gatb::core::bank;
using namespace gatb::core::kmer::impl;

using namespace gatb::core::system;
using namespace gatb::core::system::impl;

/********************************************************************************/




int main (int argc, char* argv[])
{
//    u_int64_t a=17;
//    u_int64_t b=32;
//    u_int64_t nbcreated ;
    

    
    
    
    // We define a try/catch block in case some method fails (bad filename for instance)
    try
    {
        /** We execute the tool. */
        Kissreads2().run (argc, argv);
    }
    
    catch (OptionFailure& e)
    {
        return e.displayErrors (cout);
    }
    
    catch (Exception& e)
    {
        cerr << "EXCEPTION: " << e.getMessage() << endl;
        return EXIT_FAILURE;
    }
    
    return EXIT_SUCCESS;
}
